import { Node, mergeAttributes, nodeInputRule } from '@tiptap/core';

const inputRegex = /!\[(.+|:?)]\((\S+)(?:(?:\s+)["'](\S+)["'])?\)/;
const Image = Node.create({
    name: 'image',
    defaultOptions: {
        inline: false,
        HTMLAttributes: {},
    },
    inline() {
        return this.options.inline;
    },
    group() {
        return this.options.inline ? 'inline' : 'block';
    },
    draggable: true,
    addAttributes() {
        return {
            src: {
                default: null,
            },
            alt: {
                default: null,
            },
            title: {
                default: null,
            },
        };
    },
    parseHTML() {
        return [
            {
                tag: 'img[src]',
            },
        ];
    },
    renderHTML({ HTMLAttributes }) {
        return ['img', mergeAttributes(this.options.HTMLAttributes, HTMLAttributes)];
    },
    addCommands() {
        return {
            /**
             * Add an image
             */
            setImage: (options) => ({ tr, dispatch }) => {
                const { selection } = tr;
                const node = this.type.create(options);
                if (dispatch) {
                    tr.replaceRangeWith(selection.from, selection.to, node);
                }
                return true;
            },
        };
    },
    addInputRules() {
        return [
            nodeInputRule(inputRegex, this.type, match => {
                const [, alt, src, title] = match;
                return { src, alt, title };
            }),
        ];
    },
});

export default Image;
export { Image, inputRegex };
//# sourceMappingURL=tiptap-extension-image.esm.js.map
